package de.thdeg.greiner.superpangworld.objects;

import de.thdeg.greiner.superpangworld.game.GameView;

import java.awt.*;

/**
 * A Bubble, which moves around on the screen and can be shot by the player.
 */
public class Bubble extends GameObject{

    /** The pixel art for the bubble */
    private final static String BUBBLE =
                    "    RRRR    \n"+
                    "   RWRRRR   \n"+
                    "  RWRRRRRR  \n"+
                    " RWRRRRRRRR \n"+
                    "RWRRRRRRRRRR\n"+
                    "RWRRRRRRRRRR\n"+
                    "RWRRRRRRRRWR\n"+
                    "RRRRRRRRRWWR\n"+
                    " RRRRRRRWWR \n"+
                    "  RRRRRWWR  \n"+
                    "   RRRWWR   \n"+
                    "    RRRR    \n";

    /** Flag, if the bubble flies from left to right */
    private boolean flyFromLeftToRight;

    /**
     * Create a bubble with default values.
     * @param gameView the {@link GameView} to display the bubble
     */
    public Bubble(GameView gameView){
        super(gameView);
        rotation = 90;
        size = 5;
        width = (int) size * 12;
        height = (int) size * 12;
        speedInPixel = 5;
        flyFromLeftToRight = true;
    }

    /**
     * Draws the bubble onto the canvas of the {@link GameView}.
     */
    @Override
    public void addToCanvas(){
        gameView.addBlockImageToCanvas(BUBBLE, getPosition().x, getPosition().y,size, rotation);
    }

    @Override
    public String toString() {
        return "Bubble:" + getPosition().toString();
    }

    /**
     * Moves the bubble a tick further.
     */
    @Override
    public void updatePosition(){
        if(flyFromLeftToRight && getPosition().x + width >= GameView.WIDTH){
            flyFromLeftToRight = false;
        }else if (!flyFromLeftToRight && getPosition().x <= 0){
            flyFromLeftToRight = true;
        }
        if(flyFromLeftToRight){
            getPosition().right(1);
        }else{
            getPosition().left(1);
        }
    }

    /**
     * Pop the bubble.
     */
    private void popBubble(){}

    /**
     * Freezes the time.
     */
    private void freezeTime(){}
}
